@@ -335,6 +335,12 @@ def main(argv):
         deploy.deploy_app_awx()
     elif action == 'create':
         generate_file.generator(filename_gen)
+    elif action == 'document':
+        #document artifact changes
+        pass
+    elif action == 'extract':
+        pass    
+        #change_version.modify_version()        
     elif action == '':
         print("Invalid action specified")
         return sys.exit(2)
